@@ -12,4 +12,4 @@ def app(environ, start_response):
         ('Content-Length', str(len(data)))
     ]
     start_response(status, response_headers)
-    return [data]
+    return iter([data])
