@@ -3,18 +3,24 @@
 # This file is part of gunicorn released under the MIT license. 
 # See the NOTICE for more information.
 
+from StringIO import StringIO
 import urlparse
 
-from gunicorn.util import normalize_name
-
+class BadStatusLine(Exception):
+    pass
+    
 class ParserError(Exception):
     pass
 
 class Parser(object):
-    
-    _should_close = False
-    
-    def __init__(self):
+    """ HTTP Parser compatible 1.0 & 1.1
+    This parser can parse HTTP requests and response.
+    """
+
+    def __init__(self, ptype='request', should_close=False):
+        self.status_line = ""
+        self.status_int = None
+        self.reason = ""
         self.status = ""
         self.headers = []
         self.headers_dict = {}
@@ -28,7 +34,19 @@ class Parser(object):
         self._content_len = None
         self.start_offset = 0
         self.chunk_size = 0
-        self._chunk_eof = False      
+        self._chunk_eof = False
+        self.type = ptype
+        self._should_close = should_close
+        
+    @classmethod
+    def parse_response(cls, should_close=False):
+        """ Return parser object for response"""
+        return cls(ptype='response', should_close=should_close)
+        
+    @classmethod
+    def parse_request(cls):
+        """ return parser object for requests """
+        return cls(ptype='request')
         
     def filter_headers(self, headers, buf):
         """ take a string as buffer and an header dict 
@@ -36,16 +54,17 @@ class Parser(object):
         if parsing isn't done. headers dict is updated
         with new headers.
         """
-
-        s = "".join(buf)
-        i = s.find("\r\n\r\n")
+        line = buf.getvalue()
+        i = line.find("\r\n\r\n")
         if i != -1:
-            r = s[:i]
+            r = line[:i]
             pos = i+4
-            return self.finalize_headers(headers, r, pos)
-        return -1
+            buf2 = StringIO()
+            buf2.write(line[pos:])
+            return self.finalize_headers(headers, r, buf2)
+        return False
         
-    def finalize_headers(self, headers, headers_str, pos):
+    def finalize_headers(self, headers, headers_str, buf2):
         """ parse the headers """
         lines = headers_str.split("\r\n")
                 
@@ -58,7 +77,7 @@ class Parser(object):
         _headers = {}
         hname = ""
         for line in lines:
-            if line == "\t":
+            if line.startswith('\t') or line.startswith(' '):
                 headers[hname] += line.strip()
             else:
                 try:
@@ -70,31 +89,45 @@ class Parser(object):
         headers.extend(list(_headers.items()))
         self.headers = headers
         self._content_len = int(_headers.get('Content-Length',0))
-        (_, _, self.path, self.query_string, self.fragment) = \
+        
+        if self.type == 'request':
+            (_, _, self.path, self.query_string, self.fragment) = \
                 urlparse.urlsplit(self.raw_path)
-        return pos
+        
+        return buf2
+    
+    def _parse_version(self, version):
+        self.raw_version = version.strip()
+        try:
+            major, minor = self.raw_version.split("HTTP/")[1].split(".")
+            self.version = (int(major), int(minor))
+        except IndexError:
+            self.version = (1, 0)
     
     def _first_line(self, line):
         """ parse first line """
-        self.status = status = line.strip()
-        
-        method, path, version = status.split(" ")
-        version = version.strip()
-        self.raw_version = version
+        self.status_line = status_line = line.strip()  
         try:
-            major, minor = version.split("HTTP/")[1].split(".")
-            version = (int(major), int(minor))
-        except IndexError:
-            version = (1, 0)
-
-        self.version = version
-        self.method = method.upper()
-        self.raw_path = path
+            if self.type == 'response':
+                version, self.status = status_line.split(None, 1)
+                self._parse_version(version)
+                try:
+                    self.status_int, self.reason = self.status.split(None, 1)
+                except ValueError:
+                    self.status_int =  self.status
+                self.status_int = int(self.status_int)
+            else:
+                method, path, version = status_line.split(None, 2)
+                self._parse_version(version)
+                self.method = method.upper()
+                self.raw_path = path
+        except ValueError:
+            raise BadStatusLine(line)
         
     def _parse_headerl(self, hdrs, line):
         """ parse header line"""
         name, value = line.split(":", 1)
-        name = normalize_name(name.strip())
+        name = name.strip().title()
         value = value.rsplit("\r\n",1)[0].strip()
         if name in hdrs:
             hdrs[name] = "%s, %s" % (hdrs[name], value)
@@ -110,7 +143,7 @@ class Parser(object):
             return True
         elif self.headers_dict.get("Connection") == "Keep-Alive":
             return False
-        elif self.version < (1,0):
+        elif self.version <= (1, 0):
             return True
         return False
         
@@ -141,12 +174,14 @@ class Parser(object):
             return True
         return False
         
-    def read_chunk(self, data):
-        s = "".join(data)
+    def read_chunk(self, buf):
+        line = buf.getvalue()
+        buf2 = StringIO()
+        
         if not self.start_offset:
-            i = s.find("\r\n")
+            i = line.find("\r\n")
             if i != -1:
-                chunk = s[:i].strip().split(";", 1)
+                chunk = line[:i].strip().split(";", 1)
                 chunk_size = int(chunk.pop(0), 16)
                 self.start_offset = i+2
                 self.chunk_size = chunk_size
@@ -154,40 +189,47 @@ class Parser(object):
         if self.start_offset:
             if self.chunk_size == 0:
                 self._chunk_eof = True
-                ret = '', data[:self.start_offset]
-                return ret
+                buf2.write(line[:self.start_offset])
+                return '', buf2
             else:
-                chunk = s[self.start_offset:self.start_offset+self.chunk_size]
+                chunk = line[self.start_offset:self.start_offset+self.chunk_size]
                 end_offset = self.start_offset + self.chunk_size + 2
                 # we wait CRLF else return None
-                if len(data) >= end_offset:
-                    ret = chunk, data[end_offset:]
+                if buf.len >= end_offset:
+                    buf2.write(line[end_offset:])
                     self.chunk_size = 0
-                    return ret
-        return '', data
+                    return chunk, buf2
+        return '', buf
         
-    def trailing_header(self, data):
-        s = "".join(data)
-        i = s.find("\r\n\r\n")
+    def trailing_header(self, buf):
+        line = buf.getvalue()
+        i = line.find("\r\n\r\n")
         return (i != -1)
         
-    def filter_body(self, data):
+    def filter_body(self, buf):
         """\
         Filter body and return a tuple: (body_chunk, new_buffer)
         Both can be None, and new_buffer is always None if its empty.
         """
-        dlen = len(data)
+        dlen = buf.len
         chunk = ''
+
         if self.is_chunked:
-            chunk, data = self.read_chunk(data)
+            try:
+                chunk, buf2 = self.read_chunk(buf)
+            except Exception, e:
+                raise ParserError("chunked decoding error [%s]" % str(e))
+            
             if not chunk:
-                return '', data
+                return '', buf
         else:
+            buf2 = StringIO()
             if self._content_len > 0:
                 nr = min(dlen, self._content_len)
-                chunk = "".join(data[:nr])
+                chunk = buf.getvalue()[:nr]
                 self._content_len -= nr
-                data = []
                 
         self.start_offset = 0
-        return (chunk, data)
+        buf2.seek(0, 2)
+        return (chunk, buf2)
+    
