@@ -27,9 +27,9 @@ class Worker(object):
     
     PIPE = []
 
-    def __init__(self, workerid, ppid, socket, app, timeout, conf):
+    def __init__(self, age, ppid, socket, app, timeout, conf):
         self.nr = 0
-        self.id = workerid
+        self.age = age
         self.ppid = ppid
         self.debug = conf['debug']
         self.conf = conf
@@ -45,7 +45,7 @@ class Worker(object):
         self.address = self.socket.getsockname()
         
     def __str__(self):
-        return "<Worker %s>" % self.id
+        return "<Worker %s>" % os.getpid()
         
     @property
     def pid(self):
@@ -59,7 +59,6 @@ class Worker(object):
         signal.signal(signal.SIGINT, self.handle_exit)
         
     def handle_usr1(self, sig, frame):
-        self.log.info("USR1")
         self.nr = -65536;
         try:
             map(lambda p: p.close(), self.PIPE)
@@ -123,7 +122,7 @@ class Worker(object):
             
             # If our parent changed then we shut down.
             if self.ppid != os.getppid():
-                self.log.info("Parent process changed. Closing %s" % self)
+                self.log.info("Parent changed, shutting down: %s" % self)
                 return
             
             try:
@@ -144,7 +143,7 @@ class Worker(object):
     def handle(self, client, addr):
         util.close_on_exec(client)
         try:
-            req = http.Request(client, addr, self.address, self.debug)
+            req = http.Request(client, addr, self.address, self.conf)
 
             try:
                 response = self.app(req.read(), req.start_response)
@@ -156,8 +155,13 @@ class Worker(object):
                 return 
 
             http.Response(client, response, req).send()
+        except socket.error, e:
+            if e[0] != errno.EPIPE:
+                self.log.exception("Error processing request.")
+            else:
+                self.log.warn("Ignoring EPIPE")
         except Exception, e:
-            self.log.exception("Error processing request. [%s]" % str(e))
+            self.log.exception("Error processing request.")
             try:            
                 # Last ditch attempt to notify the client of an error.
                 mesg = "HTTP/1.0 500 Internal Server Error\r\n\r\n"
